import { axiosInstance } from "./axiosInstance";
import { ApiToken, CustomerInfo } from "./types";

const API_TOKEN_NOT_FOUND_ERROR_CODE = 16;

/**
 * Get the data of customer
 * 
 * @param token The token, given from WOnD, of the customer
 * @returns the data of the customer
 */
export async function getCustomerInfo(token: ApiToken, id: number): Promise<CustomerInfo> {

    const res = await axiosInstance.get("/getCustomer", {
        params: { token, id }
    })

    if (res.data.getCustomer.result == "ERROR"){
        const code: number = res.data.getCustomer.errorCode;
        // if (code == API_TOKEN_NOT_FOUND_ERROR_CODE)
            // navigate('/')
        const msg: string = res.data.getCustomer.message;
        throw new Error(`Couldn't get user info\nError code: ${code}\nError message: ${msg}`);
    }

    const customerInfo: CustomerInfo = {
        name: res.data.getCustomer.customer.description, // yes i know...
        balance: res.data.getCustomer.customer.prepayBalanceCash
    }

    return customerInfo;
}