import { axiosInstance } from "./axiosInstance";
import { ApiToken } from "./types";


const API_INVALID_SHOP_ID_CODE = 608;

/**
 * Check whether the token of the user is valid.
 * 
 * @param token the token of the logged in customer
 * @returns whether the user's token is still valid for the backend (aka if he is still logged in)
 */
export async function isTokenValid(token: ApiToken): Promise<boolean>{
    // There is no official way to check if the token is still valid or not,
    // so after asking Daniele Comes, he said to make a call to retrieveOrders 
    // with shopId of -1 so that the DB wouldn't be queried.
    // If the answer is "Invalid field 'shopId'", then the token is valid.
    // If it isn't, it will be picked up before checking the shopId and
    // the answer will contain a certain variation of the message "Token is not valid"

    // Daniele Comes said he asked the WOnD team to make an endpoint to ask if the token is valid.

    let res = await axiosInstance.get("/retrieveOrders", { params: {
        token,
        shopId: -1
    }})

    if (res.data.retrieveOrders.result != "ERROR")
        throw new Error("The API somehow didn't answer ERROR when asking to retrieve orders from shop with id=-1... This is not normal!");

    const errorCode: number = res.data.retrieveOrders.errorCode;

    return (errorCode == API_INVALID_SHOP_ID_CODE);
}