import React, { useState } from "react";
import { createRoot } from "react-dom/client";
import { createBrowserRouter, RouterProvider } from "react-router-dom";
import { MetadataSetter, ErrorPage, Login, ForgotPassword, Reset, Transactions } from "@components";
import UserContext from '@ts/userContext'
import { ApiToken } from "@api/types";

const router = createBrowserRouter([
  {
    path: "/",
    element:
      <MetadataSetter title="Transactions" bodyClass="transactions" needsAuth>
        <Transactions />
      </MetadataSetter>,
    errorElement:
      <MetadataSetter title="Error" bodyClass="error">
        <ErrorPage />
      </MetadataSetter>
  },
  {
    path: "/login",
    element:
      <MetadataSetter title="Login" bodyClass="login">
        <Login />
      </MetadataSetter>
  },
  {
    path: "/forgot",
    element:
      <MetadataSetter title="Forgot Password" bodyClass="forgot">
        <ForgotPassword />
      </MetadataSetter>
  },
  {
    path: "/reset",
    element:
      <MetadataSetter title="Reset Password" bodyClass="reset">
        <Reset />
      </MetadataSetter>
  },
]);


const App = function () {

  const [token, setToken] = useState<ApiToken>(window.localStorage.getItem("token"));
  const [id, setId] = useState<number>(Number.parseInt(window.localStorage.getItem("customerId")));
  const userContextValue = { token, setToken, id, setId }

  return (
    <UserContext.Provider value={userContextValue}>
      <RouterProvider router={router} />
    </UserContext.Provider>
  )
}



createRoot(document.querySelector("#root")).render(
  <React.StrictMode>
    <App />
  </React.StrictMode>
);
